module.exports = defineTest({
	description:
		'Properly renders branches which refer to hoisted variables from other lexical scopes'
});
